#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lsp-test
version:              0.11.0.7
visibility:           public
id:                   lsp-test-0.11.0.7-FcU6uGiy38f68aTrEPUqMI
key:                  lsp-test-0.11.0.7-FcU6uGiy38f68aTrEPUqMI
license:              BSD-3-Clause
copyright:            2020 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:             https://github.com/bubba/lsp-test#readme
synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.Haskell.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire, and @Language.Haskell.LSP.Test@ can replay captured sessions from
    <haskell-lsp https://hackage.haskell.org/package/haskell-lsp>.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  54ac6b8835ad3db84effa39cfca954bb
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.2.1-BgKMLJR8mPH8EvrPvvjrd8:Control.Applicative.Combinators,
    Language.Haskell.LSP.Test, Language.Haskell.LSP.Test.Replay,
    Language.Haskell.LSP.Types from haskell-lsp-types-0.23.0.0-CtbBwV5Z9QZ4p55USqsHez:Language.Haskell.LSP.Types,
    Language.Haskell.LSP.Types.Capabilities from haskell-lsp-types-0.23.0.0-CtbBwV5Z9QZ4p55USqsHez:Language.Haskell.LSP.Types.Capabilities

hidden-modules:
    Language.Haskell.LSP.Test.Compat Language.Haskell.LSP.Test.Decoding
    Language.Haskell.LSP.Test.Exceptions
    Language.Haskell.LSP.Test.Files Language.Haskell.LSP.Test.Messages
    Language.Haskell.LSP.Test.Parsing Language.Haskell.LSP.Test.Server
    Language.Haskell.LSP.Test.Session

import-dirs:          /usr/lib/ghc-8.10.2/site-local/lsp-test-0.11.0.7
library-dirs:         /usr/lib/ghc-8.10.2/site-local/lsp-test-0.11.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.2/lsp-test-0.11.0.7
hs-libraries:         HSlsp-test-0.11.0.7-FcU6uGiy38f68aTrEPUqMI
depends:
    Diff-0.4.0-KyPtUOKlpskC2b7jcuQ1e4
    Glob-0.10.1-6HeWIbuEiFx5VPLlDxkpcB
    aeson-1.5.4.1-DnAbBYGYPRb2Wb6UPOkxl3
    aeson-pretty-0.8.8-LpTTCYfKkYlB0EZJRgFaEr
    ansi-terminal-0.11-Kr8IATarnGKLccmIY5TAPI
    async-2.2.2-6WjYHdzpa4C5cwFlX6aJ0s base-4.14.1.0
    bytestring-0.10.10.0 conduit-1.3.4-4OnGQk4R7UYFFlz9GXKmpp
    conduit-parse-0.2.1.0-6eHZ77oMN9T3j9nUNTSEui containers-0.6.2.1
    data-default-0.7.1.1-KLr953AsnH0rCiCUM3wfv directory-1.3.6.0
    filepath-1.4.2.1 haskell-lsp-0.23.0.0-KcARh2Oo5E5H0XkbRo3Gui
    lens-4.19.2-JSkoiVQrRhp9nCM2N7ftOG mtl-2.2.2
    parser-combinators-1.2.1-BgKMLJR8mPH8EvrPvvjrd8 process-1.6.9.0
    text-1.2.3.2 transformers-0.5.6.2 unix-2.7.2.2
    unordered-containers-0.2.13.0-7pOqjd0pRU55sA8Cia2M4w

haddock-interfaces:   /usr/share/doc/haskell-lsp-test/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

